@@ -22,8 +22,8 @@ class GitbucketControl:
 
     def disable(self):
         self.insider.remove_service(SERVICE_NAME)
+        self.systemd.stop()
         self.systemd.disable()
-        self.systemd.remove_service()
 
     def status(self):
         return self.systemd.is_active()
\ No newline at end of file
